@@ -42,6 +42,7 @@ MainWindow::MainWindow(QWidget *parent) :
 	connect (_downloader, SIGNAL(failed(Entry)), this, SLOT(_failed(Entry)));
 	connect (ui->cancelButton, SIGNAL(clicked()), this, SLOT(_remove_selected()));
 	connect (ui->actionClear, SIGNAL(triggered()), this, SLOT(_clear_selection()));
+	connect (ui->actionSelectAll, SIGNAL(triggered()), this, SLOT(_select_all()));
 	connect (ui->actionHelp, SIGNAL(triggered()), this, SLOT(_help()));
 	ui->progressBar->hide();
 
@@ -99,7 +100,7 @@ void MainWindow::_downloaded(Entry entry) {
 }
 
 void MainWindow::_failed(Entry entry) {
-//	qWarning() << "FAILED: " << entry.Album << entry.Artist;
+	qWarning() << "FAILED: " << entry.Album << entry.Artist;
 	ui->progressBar->setValue(ui->progressBar->value()+1);
 	if (ui->progressBar->value() == _total_to_download) {
 		ui->progressBar->hide();
@@ -125,8 +126,16 @@ void MainWindow::_clear_selection() {
 	ui->tableView->selectionModel()->clearSelection();
 }
 
+void MainWindow::_select_all() {
+	int size = _model->rowCount();
+	for (int i = 0; i < size; i++) {
+		ui->tableView->selectionModel()->select(_model->index(i, 0), QItemSelectionModel::Select);
+		ui->tableView->selectionModel()->select(_model->index(i, 1), QItemSelectionModel::Select);
+	}
+}
+
 void MainWindow::_help() {
-	QMessageBox::information(this, tr("Help"), tr("Album art downloader for SomePlayer and TPlayer. v.1.0\n"
+	QMessageBox::information(this, tr("Help"), tr("Album art downloader for SomePlayer and TPlayer. v.1.2\n"
 				      "Author: Nikolay Tischenko (somebody)\n\n"
 				      "This manager uses LastFM API to get album art for your music.\n"
 				      "It stores downloaded files in ~/.covers directory.\n"
